@@ -11,7 +11,8 @@ import pyotp
 from asyncpg import ConnectionDoesNotExistError
 from bybit_p2p import P2P
 from bybit_p2p._exceptions import FailedRequestError
-from pyro_client.client.filler import FileClient, cond_start_handler
+from pyro_client.client.file import FileClient
+from pyro_client.client.filler import cond_start_handler
 from pyrogram.filters import command
 from pyrogram.handlers import MessageHandler
 from tortoise.exceptions import IntegrityError, MultipleObjectsReturned
@@ -25,7 +26,7 @@ from xync_schema.models import Actor, Cond, CondSim, Pmcur, PairSide
 
 from xync_client.Abc.Agent import BaseAgentClient
 from xync_client.Abc.xtype import BaseOrderReq, FlatDict
-from xync_client.Bybit.etype.ad import AdPostRequest, AdUpdateRequest, AdDeleteRequest, Ad
+from xync_client.Bybit.etype.ad import AdPostRequest, AdUpdateRequest, AdDeleteRequest, Ad, AdStatus
 from xync_client.Bybit.etype.cred import CredEpyd
 from xync_client.Bybit.etype.order import (
     OrderRequest,
@@ -35,7 +36,7 @@ from xync_client.Bybit.etype.order import (
     OrderItem,
     OrderFull,
     Message,
-    Statuses,
+    Status,
 )
 from xync_client.loader import TORM, TOKEN
 
@@ -44,11 +45,6 @@ class NoMakerException(Exception):
     pass
 
 
-class AdsStatus(IntEnum):
-    REST = 0
-    WORKING = 1
-
-
 class AgentClient(BaseAgentClient):  # Bybit client
     host = "api2.bybit.com"
     headers = {"cookie": ";"}  # rewrite token for public methods
@@ -194,8 +190,8 @@ class AgentClient(BaseAgentClient):  # Bybit client
         delete = await self._post("/fiat/otc/user/payment/new_delete", data)
         return delete
 
-    async def switch_ads(self, new_status: AdsStatus) -> dict:
-        data = {"workStatus": new_status.name}
+    async def switch_ads(self, new_status: AdStatus) -> dict:
+        data = {"workStatus": new_status.name}  # todo: переделать на апи, там status 0 -> 1
         res = await self._post("/fiat/otc/maker/work-config/switch", data)
         return res
 
@@ -219,9 +215,14 @@ class AgentClient(BaseAgentClient):  # Bybit client
         ads = [ad for ad in list_ads if set(ad["payments"]) - {"5", "51"}]
         return float(ads[0]["price"])
 
-    def get_user_ads(self, active: bool = True) -> list:
-        uo = self._post("/fiat/otc/item/personal/list", {"page": "1", "size": "10", "status": "2" if active else "0"})
-        return uo["result"]["items"]
+    def my_ads(self, active: bool = True, page: int = 1) -> list[Ad]:
+        res = self.api.get_ads_list(size="30", page=str(page), status=AdStatus.active if active else AdStatus.sold_out)[
+            "result"
+        ]
+        ads = [Ad.model_validate(ad) for ad in res["items"]]
+        if res["count"] > 30 * page:
+            ads.extend(self.my_ads(active, page + 1))
+        return ads
 
     def get_security_token_create(self):
         data = self._post("/fiat/otc/item/create", self.create_ad_body)
@@ -479,10 +480,10 @@ class AgentClient(BaseAgentClient):  # Bybit client
             order_db, _ = await models.Order.update_or_create(
                 {
                     "amount": o.amount,
-                    "status": OrderStatus[Statuses(o.status).name],
+                    "status": OrderStatus[Status(o.status).name],
                     "created_at": int(o.createDate[:-3]),
                     "payed_at": order.transferDate != "0" and int(order.transferDate[:-3]) or None,
-                    "confirmed_at": Statuses(o.status) == Statuses.completed and int(order.updateDate[:-3]) or None,
+                    "confirmed_at": Status(o.status) == Status.completed and int(order.updateDate[:-3]) or None,
                     "appealed_at": o.status == 30 and int(order.updateDate[:-3]) or None,
                     "cred_id": ecredex.paymentType and credex.cred_id or None,
                     "taker": taker,
@@ -559,8 +560,8 @@ class AgentClient(BaseAgentClient):  # Bybit client
         taker_side: bool,
         pms: list[str],
         ceil: float,
-        volume: float = None,
         place: int = 0,
+        volume: float = None,
     ):
         k = (-1) ** int(taker_side)  # on_buy=1, on_sell=-1
         sleep_sec = 1 if set(pms) & {"volet"} and coinex.coin_id == 1 else 5
@@ -586,7 +587,7 @@ class AgentClient(BaseAgentClient):  # Bybit client
                 await sleep(15)
                 continue
             if not (cur_plc := [i for i, ad in enumerate(ads) if int(ad.userId) == self.actor.exid]):
-                logging.warning(f"No racing in {'-' if taker_side else '+'}{coinex.exid}/{curex.exid}")
+                logging.warning(f"No racing in {pms[0]} {'-' if taker_side else '+'}{coinex.exid}/{curex.exid}")
                 await sleep(15)
                 continue
             (cur_plc,) = cur_plc
@@ -960,10 +961,6 @@ def step(mad, cad) -> float:
     )
 
 
-def listen(data: dict):
-    print(data)
-
-
 class ExcCode(IntEnum):
     FixPriceLimit = 912120022
     RareLimit = 912120050
@@ -983,7 +980,8 @@ async def main():
         b: FileClient
         b.add_handler(MessageHandler(cond_start_handler, command("cond")))
         cl: AgentClient = actor.client(b)
-        # await cl.ex_client.set_pmcurexs(cookies=actor.agent.auth["cookies"])  # 617 -> 639
+        cl.my_ads(False)
+        # await cl.ex_client.set_pms(cookies=actor.agent.auth["cookies"])  # 617 -> 639
         # await cl.set_creds()
         # await cl.ex_client.set_pairs()
 
@@ -1020,11 +1018,11 @@ async def main():
 
         # await cl.actual_cond()
         await gather(
-            # cl.get_api_orders(11),  # 10, 1738357200000, 1742504399999
-            cl.battle(usdt, rub, False, ["volet"], 80.44),  # гонка в стакане покупки - мы продаем
-            cl.battle(usdt, rub, True, ["volet"], 80.9),  # гонка в стакане продажи - мы покупаем
-            cl.battle(usdt, rub, False, ["payeer"], 81.2),  # гонка в стакане покупки - мы продаем
-            cl.battle(usdt, rub, True, ["payeer"], 80.2),  # гонка в стакане продажи - мы покупаем
+            # cl.get_api_orders(),  # 10, 1738357200000, 1742504399999
+            cl.battle(usdt, rub, False, ["volet"], 80.88),  # гонка в стакане покупки - мы продаем
+            cl.battle(usdt, rub, True, ["volet"], 80.47),  # гонка в стакане продажи - мы покупаем
+            cl.battle(usdt, rub, False, ["payeer"], 81.49),  # гонка в стакане покупки - мы продаем
+            cl.battle(usdt, rub, True, ["payeer"], 80.7),  # гонка в стакане продажи - мы покупаем
             cl.battle(eth, rub, False, ["volet"], 300_000),
             cl.battle(eth, rub, True, ["volet"], 296_000),
             cl.battle(eth, rub, False, ["payeer"], 300_000),
